@@ -55,7 +55,7 @@ class BasePafy(object):
     """ Class to represent a YouTube video. """
 
     def __init__(self, video_url, basic=True, gdata=False,
-                 signature=True, size=False, callback=None, ydl_opts=None):
+                 size=False, callback=None, ydl_opts=None):
         """ Set initial values. """
         self.version = __version__
         self.videoid = extract_video_id(video_url)
